@@ -10,23 +10,22 @@
 ####################################################################
 
 
-use v5.20;
+use v5.26;
 use warnings;
 use experimental 'signatures';
 use Feature::Compat::Try;
 use Future::AsyncAwait;
 
-package Sys::Async::Virt::Callback v0.0.6;
+package Sys::Async::Virt::Callback v0.0.7;
 
 use Carp qw(croak);
 use Future::Queue;
 use Log::Any qw($log);
 
-use Protocol::Sys::Virt::Remote::XDR v0.0.6;
+use Protocol::Sys::Virt::Remote::XDR v0.0.7;
 my $remote = 'Protocol::Sys::Virt::Remote::XDR';
 
-sub new {
-    my ($class, %args) = @_;
+sub new($class, %args) {
     return bless {
         id => $args{id},
         client => $args{client},
@@ -84,7 +83,7 @@ Sys::Async::Virt::Callback - Client side proxy to remote LibVirt event source
 
 =head1 VERSION
 
-v0.0.6
+v0.0.7
 
 =head1 SYNOPSIS
 
