@@ -10,49 +10,21 @@
 ####################################################################
 
 
-use v5.20;
+use v5.26;
 use warnings;
 use experimental 'signatures';
 use Future::AsyncAwait;
 
-package Sys::Async::Virt::Connection v0.0.6;
+package Sys::Async::Virt::Connection v0.0.7;
 
 use parent qw(IO::Async::Notifier);
 
 use Carp qw(croak);
 use Log::Any qw($log);
 
-
-sub _parse_url($self, $url) {
-    my ($base, $query) = split( /\?/, $url, 2 );
-    $query //= '';
-    my %args = map {
-        s/%([0-9a-z]{2})/chr(hex($1))/gie;
-        # Encode::decode ascii -> Perl-internal????
-        $_;
-    }
-    map {
-        my ($key, $val) = split( /=/, $_, 2 );
-        $val //= '';
-        ($key, $val);
-    }
-    split( /&/, $query );
-
-    if ($base =~ m#^
-                (?<hypervisor>[a-z0-9_]+)
-                (?:\+(?<transport>[a-z0-9_]+))?
-                ://
-                (?:(?<username>[^@]*)
-                   @
-                   (?<password>.*)?)?
-                /
-                (?<type>system|session)
-                $
-                #xi) {
-        return (base => $base, %+, query => \%args);
-    }
-
-    die "Malformed hypervisor URI $url";
+sub close($self) {
+    die $log->fatal(
+        "The 'close' method must be implemented by concrete sub-classes");
 }
 
 async sub connect($self) {
@@ -70,14 +42,24 @@ async sub read($self, $type, $len) {
 }
 
 async sub write($self, @data) {
+    return if @data == 0;
+
+    # use the first data element as backpressure
+    # but don't await it here: we want to send
+    # all data into the send queue at once, so
+    # other write calls can't mix their data
+    # with ours
+    my $f = $self->{out}->write( shift @data );
+
     while (@data) {
         my $data = shift @data;
-        next unless length($data) > 0;
-        await $self->{out}->write($data);
-    }
-    return;
-}
+        next unless $data;
 
+        $self->{out}->write( $data );
+    }
+
+    return await $f;
+}
 
 1;
 
@@ -90,7 +72,7 @@ Sys::Async::Virt::Connection - Connection to LibVirt server (abstract
 
 =head1 VERSION
 
-v0.0.6
+v0.0.7
 
 =head1 SYNOPSIS
 
@@ -140,32 +122,6 @@ requested to read file descriptors).
 Writes data (passed as strings) and file descriptors (passed as arrays of
 descriptors) to the connection.
 
-=head1 INTERNAL METHODS
-
-=head2 _parse_url
-
-  my %components = $self->_parse_url($url);
-
-Returns a list of key/value pairs, with the following keys:
-
-=over 8
-
-=item * base
-
-=item * hypervisor
-
-=item * password
-
-=item * query
-
-=item * transport
-
-=item * type
-
-=item * username
-
-=back
-
 =head1 SEE ALSO
 
 L<LibVirt|https://libvirt.org>, L<Sys::Virt>
