@@ -10,12 +10,12 @@
 ####################################################################
 
 
-use v5.20;
+use v5.26;
 use warnings;
 use experimental 'signatures';
 use Future::AsyncAwait;
 
-package Sys::Async::Virt::Stream v0.0.6;
+package Sys::Async::Virt::Stream v0.0.7;
 
 use parent qw( IO::Async::Notifier );
 
@@ -23,11 +23,10 @@ use Carp qw(croak);
 use Future::Queue;
 use Log::Any qw($log);
 
-use Protocol::Sys::Virt::Remote::XDR v0.0.6;
+use Protocol::Sys::Virt::Remote::XDR v0.0.7;
 my $remote = 'Protocol::Sys::Virt::Remote::XDR';
 
-sub new {
-    my ($class, %args) = @_;
+sub new($class, %args) {
     return bless {
         id => $args{id},
         proc => $args{proc},
@@ -159,7 +158,7 @@ Sys::Async::Virt::Stream - Client side of a data transfer channel
 
 =head1 VERSION
 
-v0.0.6
+v0.0.7
 
 =head1 SYNOPSIS
 
